@@ -124,7 +124,7 @@ def do_config_host_show(sc, args):
         utils.print_item(host, hostProperties)
 
 
-@cliutils.arg("--host_name", help="Name of the host")
+@cliutils.arg("host_name", help="Name of the host")
 def do_config_host_delete(sc, args):
     """Create a config host."""
     sc.config.hosts.delete(args.host_name)
@@ -182,8 +182,8 @@ def do_config_service_create(sc, args):
     sc.config.services.create(**service)
 
 
-@cliutils.arg("--host_name", help="Name of the host")
-@cliutils.arg("--service_description")
+@cliutils.arg("host_name", help="Name of the host")
+@cliutils.arg("service_description", help="The service_description")
 def do_config_service_delete(sc, args):
     """Create a config host."""
     sc.config.services.delete(args.host_name,
@@ -229,6 +229,67 @@ def do_config_checkmodulation_delete(sc, args):
     sc.config.checkmodulations.delete(args.checkmodulation_name)
 
 
+def do_config_command_list(sc, args):
+    """List all config commands."""
+    commands = sc.config.commands.list()
+
+    if args.json:
+        print(utils.json_formatter(commands))
+    else:
+        cols = [
+            'command_name',
+            'command_line'
+        ]
+
+        formatters = {
+            'command_name': lambda x: x['command_name'],
+            'command_line': lambda x: x['command_line']
+        }
+        utils.print_list(commands, cols, formatters=formatters)
+
+
+@cliutils.arg("--command_name")
+@cliutils.arg("--command_line")
+def do_config_command_create(sc, args):
+    """Create a config check modulation."""
+    arg_names = ['command_name',
+                 'command_line']
+    command = _dict_from_args(args, arg_names)
+    sc.config.commands.create(**command)
+
+
+@cliutils.arg("--command_name", help="Name of the command")
+def do_config_command_delete(sc, args):
+    """Delete a config command."""
+    sc.config.commands.delete(args.command_name)
+
+
+@cliutils.arg("--command_name", help="Name of the command")
+def do_config_command_show(sc, args):
+    """Show a specific command."""
+    command = sc.config.commands.get(args.command_name)
+
+    if args.json:
+        print(utils.json_formatter(command))
+    elif command:
+        """ Specify the shown order and all the properties to display """
+        command_properties = [
+            'command_name', 'command_line'
+        ]
+
+        utils.print_item(command, command_properties)
+
+
+@cliutils.arg("--command_name", help="Name of the command")
+@cliutils.arg("--command_line", help="Address of the command")
+def do_config_command_update(sc, args):
+    """Update a config command."""
+    arg_names = ['command_name',
+                 'command_line']
+    command = _dict_from_args(args, arg_names)
+    sc.config.commands.update(**command)
+
+
 def do_config_reload(sc, args):
     """Trigger a config reload."""
     print(sc.config.reload_config()['message'])
@@ -260,6 +321,21 @@ def do_status_host_list(sc, args):
         utils.print_list(services, cols, formatters=formatters)
 
 
+@cliutils.arg("host_name", help="The host_name")
+def do_status_host_show(sc, args):
+    host = sc.status.hosts.get(args.host_name)
+
+    if args.json:
+        print(utils.json_formatter(host))
+    elif host:
+        hostProperties = [
+            'host_name', 'address', 'state', 'last_check',
+            'last_state_change', 'long_output', 'description', 'acknowledged',
+            'plugin_output', 'services', 'childs', 'parents',
+        ]
+        utils.print_item(host, hostProperties)
+
+
 def do_status_service_list(sc, args):
     """List all status services."""
     services = sc.status.services.list()
@@ -285,6 +361,70 @@ def do_status_service_list(sc, args):
         utils.print_list(services, cols, formatters=formatters)
 
 
+@cliutils.arg("host_name", help="Name of the host")
+@cliutils.arg("metric_name", help="Name of the metric")
+@cliutils.arg("time_begin", help="begin of the metric")
+@cliutils.arg("time_end", help="end of the metric")
+@cliutils.arg("--service_description", help="Service description")
+def do_status_metrics_list(sc, args):
+    """List all status metrics."""
+    arg_names = ['host_name',
+                 'metric_name',
+                 'time_begin',
+                 'time_end',
+                 'service_description']
+    arg = _dict_from_args(args, arg_names)
+
+    metrics = sc.status.hosts.metrics.get(**arg)
+    if args.json:
+        print(utils.json_formatter(metrics))
+    else:
+        cols = [
+            'min',
+            'max',
+            'warning',
+            'critical',
+            'value',
+            'unit'
+        ]
+
+        formatters = {
+            'min': lambda x: x.get('min', ''),
+            'max': lambda x: x.get('max', ''),
+            'warning': lambda x: x.get('warning', ''),
+            'critical': lambda x: x.get('critical', ''),
+            'value': lambda x: x.get('value', ''),
+            'unit': lambda x: x.get('unit', ''),
+        }
+        utils.print_list(metrics, cols, formatters=formatters)
+
+
+@cliutils.arg("host_name", help="Name of the host")
+@cliutils.arg("metric_name", help="Name of the metric")
+@cliutils.arg("--service_description", help="Service description")
+def do_status_metrics_show(sc, args):
+    """Give the last status metrics."""
+    arg_names = ['host_name',
+                 'metric_name',
+                 'service_description']
+    arg = _dict_from_args(args, arg_names)
+
+    metric = sc.status.hosts.metrics.get(**arg)
+    if args.json:
+        print(utils.json_formatter(metric))
+    else:
+        metricProperties = [
+            'min',
+            'max',
+            'warning',
+            'critical',
+            'value',
+            'unit'
+        ]
+
+        utils.print_item(metric, metricProperties)
+
+
 @cliutils.arg("host_name", help="Name of the host")
 @cliutils.arg("--service_description", help="Service description")
 @cliutils.arg("--time_stamp")
